#
# spec file for package libdmtx
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libdmtx
Version:        0.7.7
Release:        1.7
Summary:        Software for reading and writing Data Matrix barcodes
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/dmtx/libdmtx
Source:         https://github.com/dmtx/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         libdmtx-0.7.4.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libdmtx is open source software for reading and writing Data Matrix barcodes.
At its core libdmtx is a native shared library, allowing C/C++ programs to use
its capabilities without extra restrictions or overhead.

%package -n libdmtx0
Summary:        Software for reading and writing Data Matrix barcodes
Group:          System/Libraries

%description -n libdmtx0
libdmtx is open source software for reading and writing Data Matrix barcodes.
At its core libdmtx is a native shared library, allowing C/C++ programs to use
its capabilities without extra restrictions or overhead.

%package devel
Summary:        Software for reading and writing Data Matrix barcodes
Group:          Development/Libraries/C and C++
Requires:       libdmtx0 = %{version}

%description devel
libdmtx is open source software for reading and writing Data Matrix barcodes.
At its core libdmtx is a native shared library, allowing C/C++ programs to use
its capabilities without extra restrictions or overhead.

%prep
%autosetup -p1
./autogen.sh

%build
%configure --disable-static
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%post -n libdmtx0 -p /sbin/ldconfig
%postun -n libdmtx0 -p /sbin/ldconfig

%files -n libdmtx0
%license LICENSE
%doc AUTHORS ChangeLog KNOWNBUG README
%{_mandir}/man?/*dmtx*
%{_libdir}/libdmtx.so.*

%files devel
%{_includedir}/dmtx.h
%{_libdir}/libdmtx.so
%{_libdir}/pkgconfig/libdmtx.pc

%changelog
* Fri Jul 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.7:
  * bug 9: Prevent edifact barcode encoding '31' from user input
  * fix compiler warnings and build errors
  * properly handle error when decoding Base256 scheme
  * remove dead and irrelevant links in the README
  * Add validity checks in DecodeSchemeAscii()
  * Declare variables in DecodeSchemeAscii() locally.
  * Implement RsFindErrorLocatorPoly fix from shm0nya
-  drop libdmtx-DmtxPropRowPadBytes.patch (upstream)#
* Sun Sep  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop ImageMagick BuildRequires, unnecessary since libdmtx 0.7.4
* Thu Jun 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.7.5
  * Add support for GS-1 encoding via the FCN1 character
  * Fix dmtxDecodeMatrixRegion returning a freed pointer
  * makefile: migrating ANSI C -> C99
  * Fixed Data Mosaic encoding bug
- Change the upstream URL.
- Drop patches, now upstream:
  * libdmtx-mosaic.patch
  * libdmtx-explicit-cast.patch
- Rebase libdmtx-DmtxPropRowPadBytes.patch.
- Update the License tag, only BSD-2-Clause files are used.
* Mon Dec  7 2015 jengelh@inai.de
- Update RPM group and use a source URL
* Thu Dec  3 2015 tchvatal@suse.com
- Add few patches to improve funcitonality bnc#881387:
  * libdmtx-DmtxPropRowPadBytes.patch
  * libdmtx-explicit-cast.patch
  * libdmtx-mosaic.patch
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf, needed for kdebase4-workspace-libs-32bit
* Tue Nov 20 2012 cgiboudeaux@gmx.com
- Fix the SLES build (%%make_install not expanded)
- Fix a couple rpmlint warnings
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Jul 25 2011 coolo@novell.com
- make snprintf available to the sources
* Tue Jul 19 2011 cgiboudeaux@gmx.com
- Update to 0.7.4
  library: Relicensed to use Simplified BSD with waiver option
  library: Added new error codes and messages in dmtxencode.c
  library: Added DmtxByteList struct and supporting functions
  library: Changed file header with updated text
  library: Fixed ECC bug for 144x144 case (thanks Huver!)
  library: New Reed Solomon implementation
  library: New repository structure: libdmtx, dmtx-utils, and dmtx-wrappers
* Sun May  8 2011 cgiboudeaux@gmx.com
- Add dmtx.
